#
# spec file for package ghc-yaml
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name yaml
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.11.0.0
Release:        1.1
Summary:        Support for parsing and rendering YAML documents
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-libyaml-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-mockery-devel
BuildRequires:  ghc-raw-strings-qq-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
README and API documentation are available at
<https://www.stackage.org/package/yaml>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Mon Oct 15 2018 psimons@suse.com
- Update yaml to version 0.11.0.0.
  [#]# 0.11.0.0
  * Split out the `libyaml` and `Text.Libyaml` code into its own package. [#145](https://github.com/snoyberg/yaml/issues/145)
* Thu Oct 11 2018 psimons@suse.com
- Update yaml to version 0.10.4.0.
  [#]# 0.10.4.0
  * Add `decodeMarked` and `decodeFileMarked` functions to `Text.Libyaml`, and
    extend native bindings to extract mark information. [#157](https://github.com/snoyberg/yaml/issues/157)
* Wed Oct 10 2018 psimons@suse.com
- Update yaml to version 0.10.3.0.
  [#]# 0.10.3.0
  * Add support for anchors and aliases to Data.Yaml.Builder [#155](https://github.com/snoyberg/yaml/pull/155)
  * Fix test suite for 32 bit machines [#158](https://github.com/snoyberg/yaml/issues/158)
  [#]# 0.10.2.0
  * Add `EncodeOptions` and `FormatOptions` to control the style of the encoded YAML. [#153](https://github.com/snoyberg/yaml/pull/153)
  * Default to using literal style for multiline strings [#152](https://github.com/snoyberg/yaml/issues/152)
  [#]# 0.10.1.1
  * Correctly declare libyaml dependency on system-libyaml flag [#151](https://github.com/snoyberg/yaml/pull/151)
  [#]# 0.10.1
  * Avoid incurring a `semigroups` dependency on recent GHCs.
  * Fix a space leak that was introduced with `0.10.0` [#147](https://github.com/snoyberg/yaml/issues/147)
  [#]# 0.10.0
  * Add `decodeFileWithWarnings` which returns warnings for duplicate fields
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update yaml to version 0.9.0.
  [#] ChangeLog for yaml
  [#]# 0.9.0
  * Expose style and tags on mappings and sequences in Text.Libyaml [#141](https://github.com/snoyberg/yaml/pull/141)
  [#]# 0.8.32
  * Escape keys as necessary [#137](https://github.com/snoyberg/yaml/issues/137)
  * Support hexadecimal and octal number values [#135](https://github.com/snoyberg/yaml/issues/135)
  * More resilient `isNumeric` (should reduce cases of unneeded quoting)
  * hpackify
  * src subdir
* Fri Jul 13 2018 psimons@suse.com
- Update yaml to version 0.8.31.1.
  [#]# 0.8.31.1
  * Add a workaround for a cabal bug [haskell-infra/hackage-trustees#165](https://github.com/haskell-infra/hackage-trustees/issues/165)
  [#]# 0.8.31
  * Add `decodeThrow` and `decodeFileThrow` convenience functions.
  * Upgrade libyaml versions
  * Deprecate `decode` and `decodeEither`
* Mon May 14 2018 psimons@suse.com
- Update yaml to version 0.8.30.
  * Removed `AppSettings` mentioned in `loadYamlSettings` error message.
  * Deprecated `decodeFile` [#129](https://github.com/snoyberg/yaml/issues/129)
  * Turn off executables by default [#103](https://github.com/snoyberg/yaml/issues/103)
  * Add `Data.Yaml.TH.yamlQQ`
  * Support conduit 1.3
  * Add `Semigroup` instance [#123](https://github.com/snoyberg/yaml/pull/123)
  * Use `throwM` instead of `monadThrow`
  * Drop aeson-qq dep (incompatible with Stackage Nightly)
  * Tweaks to the executable `yaml2json` [#119](https://github.com/snoyberg/yaml/pull/119):
  - Add command-line option `-h` and `--help` to show help message
  - Error messages are now written to `stderr` instead of `stdout`
  * New encodePretty option `setConfDropNull` to drop null values from objects [#116](https://github.com/snoyberg/yaml/issues/116)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jul 17 2017 psimons@suse.com
- Update to version 0.8.23.3.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 0.8.23.1.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.8.23.
* Thu May 18 2017 psimons@suse.com
- Update to version 0.8.22.1 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 0.8.22 with cabal2obs.
* Mon Jan 30 2017 psimons@suse.com
- Update to version 0.8.21.2 with cabal2obs.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 0.8.21.1 with cabal2obs.
* Thu Oct 27 2016 psimons@suse.com
- Update to version 0.8.20 with cabal2obs.
* Mon Sep 26 2016 psimons@suse.com
- Update to version 0.8.18.7 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.8.18.6 revision 0 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 0.8.18.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.8.18 revision 0 with cabal2obs.
* Mon Jun 27 2016 mimi.vx@gmail.com
- update to 0.8.18
  * Switched yaml decode function for config file readers in Data.Yaml.Config
    to the one from Data.Yaml.Include that supports !include syntax.
* Fri Jun 10 2016 mimi.vx@gmail.com
- update to 0.8.17.2
  * Fix pretty-printing order of UnexpectedEvent's fields
* Sat Apr 16 2016 mimi.vx@gmail.com
- update to 0.8.17.1
  * workaround for Cabal bug
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 0.8.17
  * loadYamlSettingsArgs
* Tue Feb 16 2016 mimi.vx@gmail.com
- update to 0.8.16
  * Add env variable parsing. loadYamlSettings can read config values from the
    environment with Yaml that specifies an env var. The syntax is
    var: _env:ENV_VAR:default
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 0.8.15.3
  * Give a warning when compiling with GHCJS
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 0.8.15.2
  * Canonicalise Monad instances
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 0.8.15.1
  * Parse Scientific directly, avoiding loss in precision.
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 0.8.14
  * Pretty print improvements for exceptions
* Sun Aug 16 2015 mimi.vx@gmail.com
- update 0.8.13
  * Pretty module
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 0.8.12
  * Proper handling of String "+123"
* Tue Apr 28 2015 mimi.vx@gmail.com
- change libyaml deps from pkgconfig to direct libyaml-devel for SLE12 support
* Mon Apr 27 2015 mimi.vx@gmail.com
- update to 0.8.11
  * Function to print prettier parse exceptions [#59](https://github.com/snoyberg/yaml/pull/59)
* Wed Feb 25 2015 mpluskal@suse.com
- Update to 0.8.10.1:
  * Add the Data.Yaml.Include module
* Thu Oct 17 2013 peter.trommler@ohm-hochschule.de
- build against system libyaml
* Wed Oct  9 2013 sbahling@suse.com
- add %%defattr(-,root,root,-) to devel files
* Sun Oct  6 2013 sbahling@suse.com
- Initial build version 0.8.5
